/*
 * jQuery UI Radialmenu Widget 1.00
 * Copyright (c) 2013 Andreas Schaffert
 *
 * Depends:
 *   - jQuery 1.6+
 *   - jQuery UI 1.9+
 *
 * Licensed under Lesser GPL-license:
 *   http://www.gnu.org/licenses/lgpl.html
 *
*/
(function($, undefined){

$.widget( "nitroxid.radialmenu", {
	/* Standard options*/
	options: {
		buttons: [],	// the buttons on the radius
		borderWidth: 20,		
		iconSize: 16,		
		borderDistance: 32,		// the extra width between the border of the base element and the inner border of the radius
		borderColor: "lightgrey",
		borderStyle: "solid",
		withTooltip: true
	},
	base: 0,
	_create: function() {
		this.element.find("ul,ol").hide();
		
		// Extract buttons from ul or ol elements and merge with options.buttons
		var ulbuttons = [];
		this.element.find("ul,ol").children().each(function () {
			var elem = {};
			elem.className = $(this).attr("class");
			elem.tooltip = $(this).children("a").text();
			elem.link = $(this).children("a").attr("href");
			
			ulbuttons.push(elem);
		});
		$.merge(this.options.buttons,ulbuttons);
	
		// build the radius
		var radius = $("<div></div>")
			.css("position", "absolute")
			.css("width",this.element.width()+this.options.borderDistance*2)
			.css("height",this.element.width()+this.options.borderDistance*2)
			.css("border-radius",(this.element.width()/2)+this.options.borderDistance+this.options.borderWidth)	
			.css("border-width",this.options.borderWidth)
			.css("border-style",this.options.borderStyle)
			.css("border-color",this.options.borderColor)
			.css("background-color","transparent")
			.css("top", -(this.options.borderWidth+this.options.borderDistance))
			.css("left", -(this.options.borderWidth+this.options.borderDistance))
			.hide();

		radius.insertBefore(this.element.find(':first'));
		
		// calculate icon positons
		
		// (angle / 180) * Math.PI;
		var alpha = (360 / this.options.buttons.length) * 0.017453292519943295;  
		var r = (this.options.borderWidth + radius.width())/2;
		var div = (this.options.borderWidth - this.options.iconSize) / 2;
	
		// append icons
		for (var i = 0; i < this.options.buttons.length; i++) {
			var x = -(Math.cos(i*alpha)*r + this.options.iconSize + div - r);
			var y = -(Math.sin(i*alpha)*r + this.options.iconSize + div - r);
			var newbutton = $( "<a></a>" )
				.css("display","block")
				.css("position","absolute")
				.css("top",y)
				.css("left",x)
				.addClass(this.options.buttons[i].className)
				.attr("href",this.options.buttons[i].link);
			if (this.options.withTooltip) {
				newbutton.attr("title",this.options.buttons[i].tooltip).tooltip();
			}
			radius.append(newbutton);
		}
		
		this.element.hover(function() {radius.show();},function () {radius.hide();});
	}
});

})(jQuery);
